@@ -1,11 +1,13 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
-
 #include <QDialog>
 #include <QSettings>
 #include <QFile>
 #include <QDoubleSpinBox>
 #include <QMessageBox>
+#include <QTextStream>
+#include <QtCore>
+#include <QMainWindow>
 
 namespace Ui {
     class mainwindow;
